Struct krush_engine::Definition
source · pub struct Definition { /* private fields */ }Expand description
Structure where to set the arguments using Type and the callback function to be called on the command evaluation by [Engine::evaluate] crate::Value::unwrap_str()
Implementations