Struct krush_engine::Engine
source · pub struct Engine { /* private fields */ }Expand description
The place where to register your commands and run them
Implementations
sourceimpl Engine
impl Engine
sourcepub fn register_command(&mut self, name: &'static str, definition: Definition)
pub fn register_command(&mut self, name: &'static str, definition: Definition)
Adds a new command to the Engine registry with given name and Definition